@@ -12,9 +12,9 @@ BEGIN {
   $MooseX::RelatedClasses::AUTHORITY = 'cpan:RSRCHBOY';
 }
 {
-  $MooseX::RelatedClasses::VERSION = '0.007';
+  $MooseX::RelatedClasses::VERSION = '0.008';
 }
-# git description: 0.006-8-ge6e6247
+# git description: 0.007-2-gd1d1187
 
 
 # ABSTRACT: Parameterized role for related class attributes
@@ -44,9 +44,13 @@ Moose::Exporter->setup_import_methods(
 sub related_class { goto \&related_classes }
 
 sub related_classes {
-    my ($meta, %args) = @_;
+    my $meta = shift;
 
-    find_meta('MooseX::RelatedClasses')->apply($meta, %args);
+    if (@_ % 2 == 1) {
+        unshift @_, ref $_[0] ? 'names' : 'name';
+    }
+
+    find_meta('MooseX::RelatedClasses')->apply($meta, @_);
 }
 
 
@@ -188,9 +192,9 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
-=for :stopwords Chris Weyl Parameterized Namespacing
+=for :stopwords Chris Weyl Kulag <g.kulag@gmail.com> Parameterized Namespacing
 
 =head1 NAME
 
@@ -198,7 +202,7 @@ MooseX::RelatedClasses - Parameterized role for related class attributes
 
 =head1 VERSION
 
-This document describes version 0.007 of MooseX::RelatedClasses - released August 22, 2013 as part of MooseX-RelatedClasses.
+This document describes version 0.008 of MooseX::RelatedClasses - released November 11, 2013 as part of MooseX-RelatedClasses.
 
 =head1 SYNOPSIS
 
@@ -207,10 +211,14 @@ This document describes version 0.007 of MooseX::RelatedClasses - released Augus
         name => 'Thinger', namespace => undef,
     };
 
-    # ...or this (preferred):
+    # this:
     use MooseX::RelatedClasses;
     related_class name => 'Thinger', namespace => undef;
 
+    # ...or this (preferred):
+    use MooseX::RelatedClasses;
+    related_class 'Thinger', namespace => undef;
+
     # ...we get three attributes:
     #
     #   thinger_class
@@ -354,6 +362,9 @@ Takes the same options that the role takes as parameters.  That means that this:
 Use the L</names> option with an array reference of classes, and attribute
 sets will be built for all of them.
 
+    related_classes [ qw{ Thinger Dinger Finger } ];
+
+    # or longhand:
     related_classes names => [ qw{ Thinger Dinger Finger } ];
 
 =head2 Namespaces / Namespacing
@@ -372,9 +383,7 @@ related classes:
     use timeandspace::autoclean;
     use MooseX::RelatedClasses;
 
-    related_classes
-        names => [ qw{ Gallifrey Enemies::Daleks SoftwareWritten::Git } ],
-        ;
+    related_classes [ qw{ Gallifrey Enemies::Daleks SoftwareWritten::Git } ];
 
 And that will generate the expected related class attributes:
 
@@ -395,7 +404,7 @@ nothing to do with your class except that you use it, and would like to be
 able to easily tweak it on the fly.  This can be done with the C<undef>
 namespace:
 
-    related_class name => 'LWP::UserAgent', namespace => undef;
+    related_class 'LWP::UserAgent', namespace => undef;
 
 This will cause the following related class attributes to be generated:
 
@@ -451,6 +460,10 @@ feature.
 
 Chris Weyl <cweyl@alumni.drew.edu>
 
+=head1 CONTRIBUTOR
+
+Kulag <g.kulag@gmail.com>
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is Copyright (c) 2012 by Chris Weyl.
